/////////////////////////////////////////////////////////////////////////
// This file is checked in as bxversion.h.in.  The configure script
// substitutes variables and creates bxversion.h.
/////////////////////////////////////////////////////////////////////////

#define VER_STRING "1.4"
#define REL_STRING "March 27, 2002"
